@@ -28,7 +28,7 @@ use warnings;
 use Date::Language;
 use Encode qw/ decode /;
 
-our $VERSION = "5.1.6";
+our $VERSION = "5.1.7";
 
 =head2 on_generate
 
@@ -174,11 +174,18 @@ sub on_generate
 
         while ( $ids->fetch() )
         {
-            push( @$entries,
-                  Chronicle::getBlog( dbh    => $dbh,
-                                      id     => $id,
-                                      config => $config
-                                    ) );
+            my $post =
+              Chronicle::getBlog( dbh    => $dbh,
+                                  id     => $id,
+                                  config => $config
+                                );
+            if ( $config->{ 'lower-case' } )
+            {
+                $post->{ 'link' } = lc( $post->{ 'link' } );
+            }
+
+            push( @$entries, $post );
+
         }
         $ids->finish();
 
