@@ -27,7 +27,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.1.6";
+our $VERSION = "5.1.7";
 
 
 =head2 on_generate
@@ -67,11 +67,17 @@ sub on_generate
 
     while ( $recent->fetch() )
     {
-        push( @$entries,
-              Chronicle::getBlog( dbh    => $dbh,
-                                  id     => $id,
-                                  config => $config
-                                ) );
+        my $post =
+          Chronicle::getBlog( dbh    => $dbh,
+                              id     => $id,
+                              config => $config
+                            );
+        if ( $config->{ 'lower-case' } )
+        {
+            $post->{ 'link' } = lc( $post->{ 'link' } );
+        }
+
+        push( @$entries, $post );
     }
     $recent->finish();
 
