@@ -25,7 +25,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.1.6";
+our $VERSION = "5.1.7";
 
 
 =head2 on_generate
@@ -110,9 +110,20 @@ sub on_generate
                                       );
 
         #
-        #  Work out where it will be written to
+        #  The page we'll output might be down-cased.
         #
-        my $out = $config->{ 'output' } . "/" . $entry->{ 'link' }->unescaped;
+        my $page = $entry->{ 'link' }->unescaped;
+        if ( $config->{ 'lower-case' } )
+        {
+            $page = lc($page);
+            $entry->{ 'link' } = lc( $entry->{ 'link' } );
+        }
+
+        #
+        #  The complete path.
+        #
+        my $out = $config->{ 'output' } . "/" . $page;
+
         #
         #  We skip posts that are already present:
         #
@@ -156,6 +167,7 @@ sub on_generate
 
         my $c = Chronicle::load_template( $entry->{ 'template' } );
         return unless ($c);
+
         $c->param( top => $config->{ 'top' } );
         $c->param($entry);
 
