@@ -32,7 +32,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.1.6";
+our $VERSION = "5.1.7";
 
 
 =head2 on_generate
@@ -70,11 +70,17 @@ sub on_generate
 
     while ( $recent->fetch() )
     {
-        push( @$entries,
-              Chronicle::getBlog( dbh    => $dbh,
-                                  id     => $id,
-                                  config => $config
-                                ) );
+        my $post =
+          Chronicle::getBlog( dbh    => $dbh,
+                              id     => $id,
+                              config => $config
+                            );
+        if ( $config->{ 'lower-case' } )
+        {
+            $post->{ 'link' } = lc( $post->{ 'link' } );
+        }
+
+        push( @$entries, $post );
     }
     $recent->finish();
 
@@ -105,6 +111,7 @@ sub on_generate
         #  Load the template
         #
         $c = Chronicle::load_template( undef, $tmpl );
+
     }
 
 
@@ -114,7 +121,6 @@ sub on_generate
     #
     return unless ($c);
 
-
     #
     #  Add the entries.
     #
