@@ -27,7 +27,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.1.6";
+our $VERSION = "5.1.7";
 
 
 =head2 on_generate
@@ -90,6 +90,9 @@ sub on_generate
 
     while ( $sql->fetch() )
     {
+        # Handle down-cased sites.
+        $link = lc($link) if ( $config->{ 'lower-case' } );
+
         push( @$urls, { url => $config->{ 'top' } . $link } );
     }
     $sql->finish();
@@ -99,6 +102,7 @@ sub on_generate
     #  Load the template
     #
     my $template = Chronicle::load_template( undef, $tmpl );
+
     $template->param( urls => $urls ) if ($urls);
     $template->param( top => $config->{ 'top' } ) if ( $config->{ 'top' } );
 
@@ -166,4 +170,3 @@ __DATA__
   <changefreq>weekly</changefreq>
 </url>
 </urlset>
-
