@@ -25,7 +25,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.1.6";
+our $VERSION = "5.1.7";
 
 
 =head2 on_generate
@@ -124,20 +124,30 @@ sub _outputTags
 
         while ( $ids->fetch() )
         {
-            push( @$entries,
-                  Chronicle::getBlog( dbh    => $dbh,
-                                      id     => $id,
-                                      config => $config
-                                    ) );
+            my $post =
+              Chronicle::getBlog( dbh    => $dbh,
+                                  id     => $id,
+                                  config => $config
+                                );
+            if ( $config->{ 'lower-case' } )
+            {
+                $post->{ 'link' } = lc( $post->{ 'link' } );
+            }
+
+            push( @$entries, $post );
         }
 
 
         my $c = Chronicle::load_template("tag.tmpl");
         return unless ($c);
 
+        # Related tags
+        my $related = _getRelated( $dbh, $tag );
+
         $c->param( top     => $config->{ 'top' } );
         $c->param( entries => $entries ) if ($entries);
         $c->param( tag     => $tag );
+        $c->param( related => $related ) if ($related);
         open my $handle, ">:encoding(UTF-8)",
           "$config->{'output'}/tags/$tag/$index" or
           die "Failed to open";
@@ -156,6 +166,34 @@ sub _outputTags
 }
 
 
+=head2 _getRelated
+
+Return any tags related to that specified.
+
+=cut
+
+sub _getRelated
+{
+    my ( $dbh, $tag ) = (@_);
+
+    my $ret;
+
+    my $sql = $dbh->prepare(
+        "SELECT DISTINCT(a.name) FROM tags AS a JOIN tags b ON b.blog_id=a.blog_id WHERE b.name=? AND a.name != b.name ORDER BY a.name;"
+    );
+    $sql->execute($tag) or die "Failed to execute:" . $dbh->errstr();
+
+    my $found;
+    $sql->bind_columns( undef, \$found );
+
+    while ( $sql->fetch() )
+    {
+        push( @$ret, { tag => $found } );
+    }
+    $sql->finish();
+
+    return ($ret);
+}
 
 =head2 _outputTagCloud
 
