@@ -56,7 +56,7 @@ use Date::Parse;
 
 
 
-our $VERSION = "5.1.6";
+our $VERSION = "5.1.7";
 
 
 =head2 on_initiate
@@ -102,7 +102,12 @@ sub on_initiate
                                        id     => $id,
                                        config => $config
                                      );
-        delete @$data{ qw/ body truncatedbody / };    # get rid of heavy fields
+
+        $data->{ 'link' } = lc( $data->{ 'link' } )
+          if ( $config->{ 'lower-case' } );
+
+        delete @$data{ qw/ comments body tags truncatedbody / }
+          ;    # get rid of heavy fields
         push @$entries, $data;
     }
     $recent->finish();
